Summary: Library providing support for "XML Signature" and "XML Encryption" standards
Name: xmlsec1
Version: 1.2.20
Release: 3
License: MIT
Group: Development/Libraries
Source0: ftp://ftp.aleksey.com/pub/xmlsec/releases/%{name}-%{version}.tar.gz
URL: http://www.aleksey.com/xmlsec/
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root

BuildRequires: libxml2-devel >= 2.9.4-1
BuildRequires: libxslt-devel >= 1.1.29-1

Requires: libxml2 >= 2.9.4-1
Requires: libxslt >= 1.1.29-1

%description
XML Security Library is a C library based on LibXML2 and OpenSSL.
The library was created with a goal to support major XML security
standards "XML Digital Signature" and "XML Encryption".

The library is available as 32-bit and 64-bit.


%package devel
Summary: Libraries, includes, etc. to develop applications with XML Digital Signatures and XML Encryption support.
Group: Development/Libraries
Requires: %{name} = %{version}
Requires: libxml2-devel >= 2.9.4-1
Requires: libxslt-devel >= 1.1.29-1
Requires: openssl-devel >= 1.0.2j-2
Requires: zlib-devel >= 1.2.3-7

%description devel
Libraries, includes, etc. you can use to develop applications with XML Digital
Signatures and XML Encryption support.

If you are compiling a 32-bit program, no special compiler options are
needed.

If you are compiling a 64-bit program, you have to compile and link your
application with "xlc -q64" or "gcc -maix64".


%package openssl
Summary: OpenSSL crypto plugin for XML Security Library
Group: Development/Libraries
BuildRequires: openssl-devel >= 1.0.2j-2
Requires: %{name} = %{version}
Requires: libxml2 >= 2.9.4-1
Requires: libxslt >= 1.1.29-1
Requires: openssl >= 1.0.2j-2

%description openssl
OpenSSL plugin for XML Security Library provides OpenSSL based crypto services
for the xmlsec library.

The library is available as 32-bit and 64-bit.


%package openssl-devel
Summary: OpenSSL crypto plugin for XML Security Library
Group: Development/Libraries
Requires: %{name} = %{version}
Requires: %{name}-devel = %{version}
Requires: %{name}-openssl = %{version}
Requires: libxml2-devel >= 2.9.4-1
Requires: libxslt-devel >= 1.1.29-1
Requires: openssl-devel >= 1.0.2j-2
Requires: openssl >= 1.0.2j-2

%description openssl-devel
Libraries, includes, etc. for developing XML Security applications with OpenSSL.

If you are compiling a 32-bit program, no special compiler options are
needed.

If you are compiling a 64-bit program, you have to compile and link your
application with "cc -q64" or "gcc -maix64".


%prep
%setup -q


%build
# setup environment for 32-bit and 64-bit builds
export AR="ar -X32_64"
export NM="nm -X32_64"

# first build the 64-bit version
export CC="cc_r -q64"
./configure \
    --prefix=%{_prefix} \
    --mandir=%{_mandir} \
    --enable-shared --enable-static \
    --enable-mscrypto \
    --enable-aes \
    --enable-gost \
    --disable-crypto-dl \
    --disable-apps-crypto-dl \
    --without-nss \
    --without-nspr \
    --without-gcrypt \
    --without-gnutls
make %{?_smp_mflags}

cp ./src/openssl/.libs/libxmlsec1-openssl.so.1 .
cp ./src/.libs/libxmlsec1.so.1 .
make distclean

# now build the 32-bit version
export CC="cc_r"
./configure \
    --prefix=%{_prefix} \
    --mandir=%{_mandir} \
    --enable-shared --enable-static \
    --enable-mscrypto \
    --enable-aes \
    --enable-gost \
    --disable-crypto-dl \
    --disable-apps-crypto-dl \
    --without-nss \
    --without-nspr \
    --without-gcrypt \
    --without-gnutls
make %{?_smp_mflags}

# add the 64-bit shared objects to the shared library containing already the
# 32-bit shared objects
${AR} -q ./src/.libs/libxmlsec1.a ./libxmlsec1.so.1


%install
[ "${RPM_BUILD_ROOT}" != "/" ] && rm -rf ${RPM_BUILD_ROOT}
make DESTDIR=${RPM_BUILD_ROOT} install

/usr/bin/strip ${RPM_BUILD_ROOT}%{_bindir}/* || :

# add the 64-bit shared objects to the shared library containing already the
# 32-bit shared objects
/usr/bin/ar -X64 -q ${RPM_BUILD_ROOT}%{_libdir}/libxmlsec1-openssl.a ./libxmlsec1-openssl.so.1

(
  cd ${RPM_BUILD_ROOT}
  for dir in bin include lib
  do
    mkdir -p usr/${dir}
    cd usr/${dir}
    ln -sf ../..%{_prefix}/${dir}/* .
    cd -
  done
)


%clean
[ "${RPM_BUILD_ROOT}" != "/" ] && rm -rf ${RPM_BUILD_ROOT}


%files 
%defattr(-,root,system)
%doc AUTHORS ChangeLog NEWS README Copyright
%{_bindir}/xmlsec1
%{_libdir}/libxmlsec1.a
%{_mandir}/man1/xmlsec1.1*
/usr/bin/xmlsec1
/usr/lib/libxmlsec1.a


%files devel
%defattr(-,root,system)  
%doc AUTHORS HACKING ChangeLog NEWS README Copyright
%{_bindir}/xmlsec1-config
%dir %{_includedir}/%{name}
%dir %{_includedir}/%{name}/xmlsec
%{_includedir}/%{name}/xmlsec/*.h
%dir %{_includedir}/%{name}/xmlsec/private
%{_includedir}/%{name}/xmlsec/private/*
%{_libdir}/libxmlsec1.la
%{_libdir}/xmlsec1Conf.sh
%{_libdir}/pkgconfig/xmlsec1.pc
%{_mandir}/man1/xmlsec1-config.1*
%{_datadir}/doc/xmlsec1/* 
%{_datadir}/aclocal/*
/usr/bin/xmlsec1-config
/usr/include/%{name}
/usr/lib/libxmlsec1.la
/usr/lib/xmlsec1Conf.sh


%files openssl
%defattr(-,root,system)  
%{_libdir}/libxmlsec1-openssl.a
/usr/lib/libxmlsec1-openssl.a


%files openssl-devel
%defattr(-,root,system)  
%dir %{_includedir}/%{name}/xmlsec/openssl
%{_includedir}/%{name}/xmlsec/openssl/*
%{_libdir}/libxmlsec1-openssl.la
%{_libdir}/pkgconfig/xmlsec1-openssl.pc
/usr/lib/libxmlsec1-openssl.la


%changelog
* Wed Nov 16 2016 Michael Perzl <michael@perzl.org> - 1.2.20-3
- recompiled against latest versions

* Fri Mar 04 2016 Michael Perzl <michael@perzl.org> - 1.2.20-2
- recompiled against latest versions

* Fri Aug 15 2014 Michael Perzl <michael@perzl.org> - 1.2.20-1
- updated to version 1.2.20

* Fri May 03 2013 Michael Perzl <michael@perzl.org> - 1.2.19-1
- updated to version 1.2.19

* Fri May 03 2013 Michael Perzl <michael@perzl.org> - 1.2.18-2
- rebuilt against OpenSSL version 1.0.1

* Thu Sep 22 2011 Michael Perzl <michael@perzl.org> - 1.2.18-1
- updated to version 1.2.18

* Wed May 26 2010 Michael Perzl <michael@perzl.org> - 1.2.12-1
- first version for AIX V5.1 and higher
